function y_synth = tfct_synthese(X_tfct,correc,hop_s)
% y_synth = tfct_synthese(X_tfct[,correc,hop_s])
% ----------------------------------------------
%
% Fonction de synthse par tfct d'un signal. Elle renvoie le signal
% synthtis.
%
% INPUTS
% ******
% - X_tfct : Matrice TFCT du son  resynthstiser (vecteur Lfen+1 x Nt)
% - correc : Coefficient de correction  appliquer
% - hop_s  : Incrment de synthse (Lfen/4 par dfaut)
%
% OUTPUTS
% *******
% - X_tfct : Matrice issue de la TFCT de dimension Lfen+1 * Ntrames
%            Chaque colonne reprsente un spectre  un instant donn.
%
% Cr par Thomas Hzard le 23/11/2010
%


% 0. INPUTS et vrifications
% **************************
Lfen = size(X_tfct,1)-1;
if (nargin < 2)
  correc = 1;
end
if (nargin < 3)
  hop_s = round(1/4 * Lfen);
end

% 1. Initialisation des variables pour la synthse
% ************************************************
M = Lfen;                            % longueur de la fentre
ws = hanning(M,'periodic');          % dfinition de la fenetre de synthse
Is = hop_s;                          % incrment sur les temps de synthse
N = 2*M;                             % ordre de la tfd
Nt = size(X_tfct,2);                 % nombre de trames
L = (Nt-1)*Is+M;                     % longueur du signal
y = zeros(L,1);                      % signal de synthse

% 2. Synthse par tfct du signal audio
% ************************************
for r = 1:Nt;
  deb_s = (r-1)*Is+1;                     % dbut de trame de synthse 
  fin_s = deb_s + M-1;                    % dbut de trame de synthse
  X = X_tfct(:,r);                        % demi-spectre
  Y = [X ; conj(X(end-1:-1:2))];          % spectre entier 
  ys = ifft(Y,N);                         % FFT inverse
  ys = ys(1:M).* ws;                      % fentrage de synthse (OLA) 
  y(deb_s:fin_s) = y(deb_s:fin_s) + ys;   % Resynthse du signal
end

% 3. Application du coefficient de correction
% *******************************************
y_synth = y / correc;

end